==> nextcloud-app-spreed-1%3A8.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/et_EE.js <==
OC.L10N.register(
    "spreed",
    {
    "Talk" : "Talk",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "None" : "Pole",
    "User" : "Kasutaja",
    "Everyone" : "Igaüks",
    "Disabled" : "Keelatud",
    "Users" : "Kasutajad",
    "Copy link" : "Kopeeri link",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
    "Favorite" : "Lemmik",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikutesse",
    "Contacts" : "Kontaktid",
    "Groups" : "Grupid",
    "Loading" : "Laadimine",
    "Error" : "Viga",
    "Password protect" : "Parooliga kaitsmine",
    "Back" : "Tagasi",
    "Close" : "Sulge",
    "Reply" : "Vasta",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "guest" : "külaline",
    "No results" : "Vasteid ei leitud",
    "Share link" : "Jaga link",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Edit" : "Redigeeri",
    "Limit to groups" : "Luba gruppidele",
    "Save changes" : "Salvesta muudatused",
    "Saved!" : "Salvestatud!",
    "Name" : "Nimi",
    "Saved" : "Salvestatud",
    "Password" : "Parool",
    "Cancel" : "Loobu",
    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
    "Android app" : "Androidi rakendus",
    "iOS app" : "iOS-i rakendus",
    "Copy" : "Kopeeri",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘+C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl+C.",
    "Share" : "Jaga",
    "Change password" : "Muuda parooli",
    "Rename" : "Nimeta ümber",
    "Send" : "Saada",
    "Error while sharing" : "Viga jagamisel",
    "Favorited" : "Lemmikud",
    ", " : ", "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A8.0.9-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/et_EE.js <==
OC.L10N.register(
    "spreed",
    {
    "Talk" : "Talk",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "Limit to groups" : "Luba gruppidele",
    "Everyone" : "Igaüks",
    "Save changes" : "Salvesta muudatused",
    "Saved!" : "Salvestatud!",
    "None" : "Pole",
    "User" : "Kasutaja",
    "Disabled" : "Keelatud",
    "Users" : "Kasutajad",
    "Name" : "Nimi",
    "Saved" : "Salvestatud",
    "Copy link" : "Kopeeri link",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
    "Favorite" : "Lemmik",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikutesse",
    "Contacts" : "Kontaktid",
    "Loading" : "Laadimine",
    "Groups" : "Grupid",
    "Error" : "Viga",
    "Password protect" : "Parooliga kaitsmine",
    "Back" : "Tagasi",
    "Close" : "Sulge",
    "Reply" : "Vasta",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "guest" : "külaline",
    "No results" : "Vasteid ei leitud",
    "Settings" : "Seaded",
    "Edit" : "Redigeeri",
    "Dismiss" : "Jäta vahele",
    "Share link" : "Jaga link",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Grid view" : "Ruudustikvaade",
    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
    "Password" : "Parool",
    "Android app" : "Androidi rakendus",
    "iOS app" : "iOS-i rakendus",
    "Copy" : "Kopeeri",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘+C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl+C.",
    "Cancel" : "Loobu",
    "Change password" : "Muuda parooli",
    "Rename" : "Nimeta ümber",
    "Send" : "Saada",
    "Share" : "Jaga",
    "Error while sharing" : "Viga jagamisel",
    "Favorited" : "Lemmikud"
},
"nplurals=2; plural=(n != 1);");
